import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage the Tls Private Key upload
 *
 * @schema CfnPrivateKeysProps
 */
export interface CfnPrivateKeysProps {
    /**
     * Resource type. [Default tls_private_key]
     *
     * @schema CfnPrivateKeysProps#Type
     */
    readonly type?: CfnPrivateKeysPropsType;
    /**
     * @schema CfnPrivateKeysProps#Attributes
     */
    readonly attributes: Attributes;
}
/**
 * Converts an object of type 'CfnPrivateKeysProps' to JSON representation.
 */
export declare function toJson_CfnPrivateKeysProps(obj: CfnPrivateKeysProps | undefined): Record<string, any> | undefined;
/**
 * Resource type. [Default tls_private_key]
 *
 * @schema CfnPrivateKeysPropsType
 */
export declare enum CfnPrivateKeysPropsType {
    /** tls_private_key */
    TLS_PRIVATE_KEY = "tls_private_key"
}
/**
 * @schema Attributes
 */
export interface Attributes {
    /**
     * The contents of the private key. Must be a PEM-formatted key. Not returned in response body.
     *
     * @schema Attributes#Key
     */
    readonly key: string;
    /**
     * A customizable name for your private key
     *
     * @schema Attributes#Name
     */
    readonly name?: string;
    /**
     * @schema Attributes#KeyType
     */
    readonly keyType?: string;
    /**
     * @schema Attributes#KeyLength
     */
    readonly keyLength?: number;
    /**
     * @schema Attributes#PublicKeySha1
     */
    readonly publicKeySha1?: string;
    /**
     * @schema Attributes#Replace
     */
    readonly replace?: boolean;
    /**
     * @schema Attributes#CreatedAt
     */
    readonly createdAt?: Date;
}
/**
 * Converts an object of type 'Attributes' to JSON representation.
 */
export declare function toJson_Attributes(obj: Attributes | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Fastly::Tls::PrivateKeys`
 *
 * @cloudformationResource Fastly::Tls::PrivateKeys
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-fastly-resource-providers
 */
export declare class CfnPrivateKeys extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Fastly::Tls::PrivateKeys";
    /**
     * Resource props.
     */
    readonly props: CfnPrivateKeysProps;
    /**
     * Attribute `Fastly::Tls::PrivateKeys.Id`
     * @link https://github.com/aws-ia/cloudformation-fastly-resource-providers
     */
    readonly attrId: string;
    /**
     * Create a new `Fastly::Tls::PrivateKeys`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnPrivateKeysProps);
}
